//=============================================================================
// CDataManager.
//=============================================================================
class CDataManager expands Triggers;

var(EditorTools) bool				ShowImagesInEditor;
var(EditorTools) bool				ShowTextsInEditor;
var(EditorTools) bool				ShowButtonsInEditor;

var() ComputerBase 		Computer;			//The computer Actor
var() bool				DoBackup;			//Copies everything from the Computer on BeginPlay
var() bool				LeaveCursor;		//should cursor data be reset on AT_Reset

var() enum EActionType
{
	AT_SetNew, 	// Sets new data in the Computer
	AT_Reset,	// resets computer to 0 on trigger.
	AT_Reset_And_SetNew, //resets old and sets new data.
} ActionType;		

struct CMessage									//Message struct
{
	var() bool				DoChange;			//Should it change?
	var() string 			Message; 			//message displayed on the screen
	var() Font 				MessageFont;				//Font of the message
	var() color 			FontColor;			//Font color
	var() float 			MessagePos_Y;				//vertical position on the screen
	var() float 			MessagePos_X;				//Horisontal position on the screen
};

struct CImage									//Image struct
{
	var() bool				DoChange;			//Should it change?
	var() texture 			Image;
	//SIZE
	var() float 			ImagePos_X;
	var() float 			ImagePos_Y;
	var() float 			ImageScale_X;
	var() float 			ImageScale_Y;
	var() float 			ImageTile_X;
	var() float 			ImageTile_Y;

	//Pan
	var() int 				ImagePan_X;
	var() int 				ImagePan_Y;
};

struct CButton									//Button struct
{
	var() bool				DoChange;
	Var() name 				Action;				//Event called when button is pressed
	Var() float 			ButtonPos_X;			//Horizontal position of a button
	Var() float 			ButtonSize_X;		//Horizontal size of a button
	Var() float 			ButtonPos_Y;			//Vertical position of a button
	Var() float 			ButtonSize_Y;		//Vertical size of a button
	Var() sound 			ActivateSound;
	var() bool				bHighlightButton;	//Should I make an image on the button?
	var() int				HighlightImageNo;	//Image I should make a highlight
	var() bool				TbChangeTextColor;	//whether a button should change color of a text
	var() int				TTextNo;			//No of a text that should change
	var() color				TColor;				//The new color of a text
	var bool				bIsChange;			//for colors stuff, if true button should have changed color
	var() bool				bDoHighlightAnim;	//Whether should do animation of the Highlight image
	Var() float				AnimAddSpeed_X;		//value addet in button animation on X, and Y;
	Var() float				AnimAddSpeed_Y;

	var() enum AType							//Types of button animation
	{
		AT_Left_To_Right,
		AT_Right_To_Left,
		AT_Up_To_Down,
		AT_Down_To_Up,
		AT_Righ_And_Left,
		AT_Up_And_Down,
		AT_All_Directions,
	} AnimType;	
};

struct CCursor									//Cursor struct
{
	var() bool				DoChange;			//Should it change?
	var() texture 			NonButtonCursor;
	var() texture 			OnButtonCursor;
	var() float 			ImagePos_X; 			// START OF SHOWING TEXTURE
	var() float 			ImagePos_Y; 			// START OF SHOWING TEXTURE
	var() float 			ImageScale_X;			// END OF SHOWING TEXTURE
	var() float 			ImageScale_Y;			// END OF SHOWING TEXTURE
	var() float 			ImageTile_X;			// END OF SHOWING TEXTURE
	var() float 			ImageTile_Y;			// END OF SHOWING TEXTURE
};

//=============================================================================
// Lets gather the structs into one.
//=============================================================================

var() CMessage Change_Text[32]; 
var() CImage Change_Image[32]; 
var() CButton Change_Button[32]; 
var() CCursor Change_Cursor;

function postbeginplay()
{
	if(DoBackup)
	{
		computer.copy(self);
	}
}

function Trigger( actor Other, pawn EventInstigator )
{
	local int n;

	if(computer != none)
	{
		if(ActionType == AT_SetNew)
		{
			for (n=0;n<32;n++)
			{
				if(Change_Text[n].DoChange)
					RunSetNewMessage(n, Change_Text[n].Message, Change_Text[n].MessageFont, Change_Text[n].FontColor, 
														Change_Text[n].MessagePos_Y, Change_Text[n].MessagePos_X);
				if(Change_Image[n].DoChange)
					RunSetNewImage(n, Change_Image[n].Image, Change_Image[n].ImagePos_X, Change_Image[n].ImagePos_Y, Change_Image[n].ImageScale_X, 
					Change_Image[n].ImageScale_Y, Change_Image[n].ImageTile_X, Change_Image[n].ImageTile_Y, Change_Image[n].ImagePan_X, 
					Change_Image[n].ImagePan_y);

				if( Change_Button[n].DoChange)
					RunSetNewButton(N, Change_Button[n].Action, Change_Button[n].ButtonPos_X, Change_Button[n].ButtonPos_Y, 
					Change_Button[n].ButtonSize_X, Change_Button[n].ButtonSize_Y, Change_Button[n].ActivateSound, Change_Button[n].bHighlightButton, 
					Change_Button[n].HighlightImageNo, Change_Button[n].TbChangeTextColor, Change_Button[n].TTextNo, Change_Button[n].TColor, 
					Change_Button[n].bDoHighlightAnim, Change_Button[n].AnimAddSpeed_X, Change_Button[n].AnimAddSpeed_Y);
				if(Change_Cursor.DoChange)
				{
					computer.Computer_Cursor.NonButtonCursor = Change_Cursor.NonButtonCursor;
					computer.Computer_Cursor.OnButtonCursor = Change_Cursor.OnButtonCursor;
					computer.Computer_Cursor.ImagePos_X = Change_Cursor.ImagePos_X;
					computer.Computer_Cursor.ImagePos_Y = Change_Cursor.ImagePos_Y ;
					computer.Computer_Cursor.ImageScale_X = Change_Cursor.ImageScale_X;
					computer.Computer_Cursor.ImageScale_Y = Change_Cursor.ImageScale_Y ;
					computer.Computer_Cursor.ImageTile_X = Change_Cursor.ImageTile_X;
					computer.Computer_Cursor.ImageTile_Y = Change_Cursor.ImageTile_Y;
				}
			}
		}
		if(ActionType == AT_Reset_And_SetNew)
		{
			computer.reset();
			for (n=0;n<32;n++)
			{
				if(Change_Text[n].DoChange)
					RunSetNewMessage(n, Change_Text[n].Message, Change_Text[n].MessageFont, Change_Text[n].FontColor, 
														Change_Text[n].MessagePos_Y, Change_Text[n].MessagePos_X);
				if(Change_Image[n].DoChange)
					RunSetNewImage(n, Change_Image[n].Image, Change_Image[n].ImagePos_X, Change_Image[n].ImagePos_Y, Change_Image[n].ImageScale_X, 
					Change_Image[n].ImageScale_Y, Change_Image[n].ImageTile_X, Change_Image[n].ImageTile_Y, Change_Image[n].ImagePan_X, 
					Change_Image[n].ImagePan_y);

				if( Change_Button[n].DoChange)
					RunSetNewButton(N, Change_Button[n].Action, Change_Button[n].ButtonPos_X, Change_Button[n].ButtonPos_Y, 
					Change_Button[n].ButtonSize_X, Change_Button[n].ButtonSize_Y, Change_Button[n].ActivateSound, Change_Button[n].bHighlightButton, 
					Change_Button[n].HighlightImageNo, Change_Button[n].TbChangeTextColor, Change_Button[n].TTextNo, Change_Button[n].TColor,
					Change_Button[n].bDoHighlightAnim, Change_Button[n].AnimAddSpeed_X, Change_Button[n].AnimAddSpeed_Y);
				if(Change_Cursor.DoChange)
				{
					ChangeCursor();
				}
			}
		}
		if(ActionType == AT_Reset)
		{
			computer.reset();
		}
	}
}

function RunSetNewMessage(int No, string Message, font MessageFont, color FontColor, float MessagePos_Y, float MessagePos_X)
{
	computer.SetNewMessage(No, Message, MessageFont, FontColor, MessagePos_Y, MessagePos_X);
}

function RunSetNewImage(int No, texture Image, float ImagePos_X, float ImagePos_Y, float ImageScale_X, float ImageScale_Y, float ImageTile_X, float ImageTile_Y, float ImagePan_X, float ImagePan_Y)
{
	computer.SetNewImage(No, Image, ImagePos_X, ImagePos_Y, ImageScale_X, ImageScale_Y, ImageTile_X, ImageTile_Y, ImagePan_X, ImagePan_Y);
}

function RunSetNewButton(int No, name Action, float ButtonPos_X, float ButtonPos_Y, float ButtonSize_X, float ButtonSize_Y, sound ActivateSound, bool bHighlightButton, int HighlightImageNo, bool TbChangeTextColor, int TTextNo, color TColor, bool bDoHighlightAnim, float AnimAddSpeed_X, float AnimAddSpeed_Y)
{
	local int AT;

	if(Change_Button[no].AnimType == AT_Left_To_Right)
		AT = 0;
	if(Change_Button[no].AnimType == AT_Right_To_Left)
		AT = 1;
	if(Change_Button[no].AnimType == AT_Up_To_Down)
		AT = 2;
	if(Change_Button[no].AnimType == AT_Down_To_Up)
		AT = 3;
	if(Change_Button[no].AnimType == AT_Righ_And_Left)
		AT = 4;
	if(Change_Button[no].AnimType == AT_Up_And_Down)
		AT = 5;
	if(Change_Button[no].AnimType == AT_All_Directions)
		AT = 6;

	Computer.SetNewButton(No, Action, ButtonPos_X, ButtonPos_Y, ButtonSize_X, ButtonSize_Y, ActivateSound, bHighlightButton, HighlightImageNo, TbChangeTextColor, TTextNo, TColor, bDoHighlightAnim, AnimAddSpeed_X, AnimAddSpeed_Y, AT);
}

function ChangeCursor()
{
	computer.Computer_Cursor.NonButtonCursor = Change_Cursor.NonButtonCursor;
	computer.Computer_Cursor.OnButtonCursor = Change_Cursor.OnButtonCursor;
	computer.Computer_Cursor.ImagePos_X = Change_Cursor.ImagePos_X;
	computer.Computer_Cursor.ImagePos_Y = Change_Cursor.ImagePos_Y ;
	computer.Computer_Cursor.ImageScale_X = Change_Cursor.ImageScale_X;
	computer.Computer_Cursor.ImageScale_Y = Change_Cursor.ImageScale_Y ;
	computer.Computer_Cursor.ImageTile_X = Change_Cursor.ImageTile_X;
	computer.Computer_Cursor.ImageTile_Y = Change_Cursor.ImageTile_Y;
}

function CopyingMessages(int N, string Message, Font MessageFont, Color FontColor, Float MessagePos_Y, Float MessagePos_X)
{
	Change_Text[n].Message = Message;
	Change_Text[n].MessageFont = MessageFont;
	Change_Text[n].FontColor = FontColor;
	Change_Text[n].MessagePos_Y = MessagePos_Y;
	Change_Text[n].MessagePos_X = MessagePos_X;
	Change_Text[n].DoChange = True;
}

function CopyingImages(int N, texture Image, Float ImagePos_X, Float ImagePos_Y, Float ImageScale_X, Float ImageScale_Y, Float ImageTile_X, Float ImageTile_Y, Float ImagePan_X,Float ImagePan_Y)
{
	Change_Image[n].Image = Image;
	Change_Image[n].ImagePos_X = ImagePos_X;
	Change_Image[n].ImagePos_Y = ImagePos_Y;
	Change_Image[n].ImageScale_X = ImageScale_X;
	Change_Image[n].ImageScale_Y = ImageScale_Y;
	Change_Image[n].ImageTile_X = ImageTile_X;
	Change_Image[n].ImageTile_Y = ImageTile_Y;
	Change_Image[n].ImagePan_X = ImagePan_Y;
	Change_Image[n].ImagePan_Y = ImagePan_Y;
	Change_Image[n].DoChange = True;
}

function CopyingButtons(int N, Name Action, Float ButtonPos_X, Float ButtonPos_Y, Float ButtonSize_X, Float ButtonSize_Y, Sound ActivateSound, Bool bHighlightButton, Int HighlightImageNo, Bool TbChangeTextColor, Int TTextNo, Color TColor, Bool bDoHighlightAnim, Float AnimAddSpeed_X, Float AnimAddSpeed_Y, Int AT)
{

	Change_Button[n].Action = Action;
	Change_Button[n].ButtonPos_X = ButtonPos_X;
	Change_Button[n].ButtonPos_Y = ButtonPos_Y;
	Change_Button[n].ButtonSize_X = ButtonSize_X;
	Change_Button[n].ButtonSize_Y = ButtonSize_Y;
	Change_Button[n].ActivateSound = ActivateSound;
	Change_Button[n].bHighlightButton = bHighlightButton;
	Change_Button[n].HighlightImageNo = HighlightImageNo;
	Change_Button[n].TbChangeTextColor = TbChangeTextColor;
	Change_Button[n].TTextNo = TTextNo;
	Change_Button[n].TColor = TColor;
	Change_Button[n].bDoHighlightAnim = bDoHighlightAnim;
	Change_Button[n].AnimAddSpeed_X = AnimAddSpeed_X;
	Change_Button[n].AnimAddSpeed_Y = AnimAddSpeed_Y;
	Change_Button[n].DoChange = True;

	if(AT == 0)
		Change_Button[n].AnimType = AT_Left_To_Right;
	if(AT == 1)
		Change_Button[n].AnimType = AT_Right_To_Left;
	if(AT == 2)
		Change_Button[n].AnimType = AT_Up_To_Down;
	if(AT == 3)
		Change_Button[n].AnimType = AT_Down_To_Up;
	if(AT == 4)
		Change_Button[n].AnimType = AT_Righ_And_Left;
	if(AT == 5)
		Change_Button[n].AnimType = AT_Up_And_Down;
	if(AT == 6)
		Change_Button[n].AnimType = AT_All_Directions;
}

event DrawEditorSelection(Canvas c)
{
	local Font f;
	local int offset, l;

	offset = 0;
	f = c.font;

	c.style = 2;

	c.font = font'qfonts.CourMed';

	c.drawColor = makeColor(255, 255, 127); 

	c.setPos(8, c.clipy-64);
	c.drawText("Tag"@":"@Tag@"    "@name, true);
	c.drawColor = makeColor(255, 255, 127); 
	c.setPos(8, c.clipy-48);
	c.drawColor = makeColor(127, 255, 255); 
	if(ActionType == AT_SetNew)
		c.drawText("Sets new data, ignores old.", true);
	else if(ActionType == AT_Reset)
		c.drawText("Leaves Computer blank.", true);
	else
		c.drawText("Resets all data and then sets new.", true);
	if(DoBackup)
	{
		c.setPos(8, c.clipy-32);
		c.drawColor = makeColor(127, 255, 192); 
		c.drawText("Creates Computer's data backup at startup.", true);
	}
	c.setPos(8, c.clipy-16);
	c.drawColor = makeColor(255, 255, 255); 
	c.drawText("Computer :"@Computer, true);

	c.font = font'qfonts.GothSmall';
	c.setPos(c.clipx-64, c.clipy-12);
	c.drawColor = makeColor(64, 64, 128); 
	c.drawText("Z-eNzYmE");

	if(ShowImagesInEditor)
	{
			c.drawColor = makeColor(255, 255, 255);
			c.SetPos(0, 0);
			c.style = 3;
			c.DrawTile(Texture'QComputers.BluePanel01.BPanel05', 256, 256, 0, 0, 128, 128);

		for (l=0;l<32;l++)
		{
			if(Change_Image[l].Image != none && Change_Image[l].DoChange == True)
			{
				c.drawColor = makeColor(255, 255, 255);
				c.SetPos(Change_Image[l].ImagePos_X, Change_Image[l].ImagePos_Y);

				c.DrawTile(Change_Image[l].Image, Change_Image[l].ImageScale_X, Change_Image[l].ImageScale_Y, 0, 0, Change_Image[l].Image.uclamp, Change_Image[l].Image.Vclamp);
			}
		}
	}

	if(ShowTextsInEditor)
	{
		for (l=0;l<32;l++)
		{
			if(Change_Text[l].message != "" && Change_Text[l].MessageFont != none && Change_Text[l].DoChange == True)
			{
				c.style = 2;
				c.setPos(Change_Text[l].MessagePos_X, Change_Text[l].MessagePos_Y);
				c.font = Change_Text[l].MessageFont;
				c.drawColor = makeColor(Change_Text[l].FontColor.R, Change_Text[l].FontColor.G, Change_Text[l].FontColor.B);
				c.drawText(Change_Text[l].message);
			}
		}
	}

	if(ShowButtonsInEditor)
	{
		c.style = 3;
		for (l=0;l<32;l++)
		{
			if(Change_Button[l].Action != 'none' && Change_Button[l].DoChange == True)
			{
				c.drawColor = makeColor(255, 255, 255);
				c.SetPos(Change_Button[l].ButtonPos_X, Change_Button[l].ButtonPos_Y);

				c.DrawTile(Texture'PlayrShp.Base.DANGER', Change_Button[l].ButtonSize_X, Change_Button[l].ButtonSize_Y, 0, 0, Change_Button[l].ButtonSize_X*4, Change_Button[l].ButtonSize_Y*4);

				c.font = font'qfonts.CourMed';
				c.drawColor = makeColor(255, 192, 192);
				c.drawText("-"$l$":"@Change_Button[l].Action);

			}
		}
	}

	c.font = f;
}

defaultproperties
{
				bEditorSelectRender=True
				Style=STY_Masked
				Texture=Texture'NWG.Icons.FolderIco'
}
